@@ -14,6 +14,11 @@ from phlogs.phlogs import phlogger
 import ast
 
 
+DAGS_S3_PATH = 's3fs-ph-airflow'
+TEMPLATE_BUCKET = 'ph-platform'
+TEMPLATE_VERSION = '2020-08-10'
+
+
 class PhContextFacade(object):
     """The Pharbers Max Job Command Line Interface (CLI) Command Context Entry
 
@@ -115,8 +120,8 @@ class PhContextFacade(object):
         config = PhYAMLConfig(self.path)
         subprocess.call(["mkdir", "-p", self.path])
         subprocess.call(["touch", self.path + "/__init__.py"])
-        s3.copy_object_2_file("ph-cli-dag-template", "template/phjob.tmp", self.path + "/phjob.py")
-        s3.copy_object_2_file("ph-cli-dag-template", "template/phconf.yaml", self.path + "/phconf.yaml")
+        s3.copy_object_2_file(TEMPLATE_BUCKET, TEMPLATE_VERSION+"/template/python/phcli/maxauto/phjob.tmp", self.path + "/phjob.py")
+        s3.copy_object_2_file(TEMPLATE_BUCKET, TEMPLATE_VERSION+"/template/python/phcli/maxauto/phconf.yaml", self.path + "/phconf.yaml")
         config.load_yaml()
         w = open(self.path + "/phjob.py", "a")
         w.write("def execute(")
@@ -133,7 +138,7 @@ class PhContextFacade(object):
         w.close()
 
         e = open(self.path + "/phmain.py", "w")
-        f_lines = s3.get_object_lines("ph-cli-dag-template", "template/phmain.tmp")
+        f_lines = s3.get_object_lines(TEMPLATE_BUCKET, TEMPLATE_VERSION+"/template/python/phcli/maxauto/phmain.tmp")
 
         s = []
         for arg in config.spec.containers.args:
@@ -169,23 +174,23 @@ class PhContextFacade(object):
     def command_combine_exec(self):
         phlogger.info("command combine")
         subprocess.call(["mkdir", "-p", self.path])
-        s3.copy_object_2_file("ph-cli-dag-template", "template/phdag.yaml", self.path + "/phdag.yaml")
+        s3.copy_object_2_file(TEMPLATE_BUCKET, TEMPLATE_VERSION+"/template/python/phcli/maxauto/phdag.yaml", self.path + "/phdag.yaml")
 
     def command_publish_exec(self):
         phlogger.info("command publish")
         for _, dirs, _ in os.walk(self.dag_path):
             for key in dirs:
                 if (not key.startswith(".")) & (not key.startswith("__pycache__")):
-                    s3.put_object("s3fs-ph-storage", "airflow/dags/phjobs/" + key + "/phmain.py",
+                    s3.put_object(DAGS_S3_PATH, "airflow/dags/phjobs/" + key + "/phmain.py",
                                   self.dag_path + key + "/phmain.py")
-                    # s3.put_object("s3fs-ph-storage", "airflow/dags/phjobs/" + key + "/phjob.zip", self.dag_path + key + "/phjob.zip")
-                    s3.put_object("s3fs-ph-storage", "airflow/dags/phjobs/" + key + "/phjob.py",
+                    # s3.put_object(DAGS_S3_PATH, "airflow/dags/phjobs/" + key + "/phjob.zip", self.dag_path + key + "/phjob.zip")
+                    s3.put_object(DAGS_S3_PATH, "airflow/dags/phjobs/" + key + "/phjob.py",
                                   self.dag_path + key + "/phjob.py")
-                    s3.put_object("s3fs-ph-storage", "airflow/dags/phjobs/" + key + "/args.properties",
+                    s3.put_object(DAGS_S3_PATH, "airflow/dags/phjobs/" + key + "/args.properties",
                                   self.dag_path + key + "/args.properties")
         for key in os.listdir(self.dag_path):
             if os.path.isfile(self.dag_path + key):
-                s3.put_object("s3fs-ph-storage", "airflow/dags/" + key, self.dag_path + key)
+                s3.put_object(DAGS_S3_PATH, "airflow/dags/" + key, self.dag_path + key)
 
     def command_run_exec(self):
         phlogger.info("run")
@@ -218,7 +223,7 @@ class PhContextFacade(object):
 
         subprocess.call(["mkdir", "-p", self.dag_path])
         w = open(self.dag_path + "/ph_dag_" + config.spec.dag_id + ".py", "a")
-        f_lines = s3.get_object_lines("ph-cli-dag-template", "template/phgraphtemp.tmp")
+        f_lines = s3.get_object_lines(TEMPLATE_BUCKET, TEMPLATE_VERSION+"/template/python/phcli/maxauto/phgraphtemp.tmp")
         for line in f_lines:
             line = line + "\n"
             if line == "$alfred_import_jobs\n":
@@ -239,7 +244,7 @@ class PhContextFacade(object):
                         .replace("$alfred_dag_timeout", str(config.spec.dag_timeout)) \
                         .replace("$alfred_start_date", str(config.spec.start_date))
                 )
-        jf = s3.get_object_lines("ph-cli-dag-template", "template/phDagJob.tmp")
+        jf = s3.get_object_lines(TEMPLATE_BUCKET, TEMPLATE_VERSION+"/template/python/phcli/maxauto/phDagJob.tmp")
         for jt in config.spec.jobs:
             # jf.seek(0)
             for line in jf:
@@ -268,8 +273,8 @@ class PhContextFacade(object):
         if self.context != "":
             udags = ast.literal_eval(self.context.replace(" ", ""))
         phlogger.info(udags)
-        submit_prefix = "s3a://s3fs-ph-storage/airflow/dags/phjobs/" + self.path + "/"
-        args = s3.get_object_lines("s3fs-ph-storage", "airflow/dags/phjobs/" + self.path + "/args.properties")
+        submit_prefix = "s3a://"+DAGS_S3_PATH+"/airflow/dags/phjobs/" + self.path + "/"
+        args = s3.get_object_lines(DAGS_S3_PATH, "airflow/dags/phjobs/" + self.path + "/args.properties")
         access_key = os.getenv("AWS_ACCESS_KEY_ID")
         secret_key = os.getenv("AWS_SECRET_ACCESS_KEY")
         current_user = os.getenv("HADOOP_PROXY_USER")
@@ -294,7 +299,7 @@ class PhContextFacade(object):
                    "--jars",
                    "s3a://ph-stream/jars/aws/aws-java-sdk-1.11.682.jar,s3a://ph-stream/jars/aws/aws-java-sdk-core-1.11.682.jar,s3a://ph-stream/jars/aws/aws-java-sdk-s3-1.11.682.jar,s3a://ph-stream/jars/hadoop/hadoop-aws-2.9.2.jar",
                    "--py-files",
-                   "s3a://s3fs-ph-storage/airflow/dags/phjobs/common/click.zip,s3a://s3fs-ph-storage/airflow/dags/phjobs/common/phcli.zip," + submit_prefix + "phjob.py",
+                   "s3a://"+DAGS_S3_PATH+"/airflow/dags/phjobs/common/click.zip,s3a://"+DAGS_S3_PATH+"/airflow/dags/phjobs/common/phcli.zip," + submit_prefix + "phjob.py",
                    submit_prefix + "phmain.py"]
 
         cur_key = ""
